==> channelpack-0.6.1.tar.gz: channelpack-0.6.1/setup.py <==
from setuptools import setup, find_packages
import codecs
import os
import re

here = os.path.abspath(os.path.dirname(__file__))

def read(*parts):
    # intentionally *not* adding an encoding option to open, See:
    #   https://github.com/pypa/virtualenv/issues/201#issuecomment-3145690
    return codecs.open(os.path.join(here, *parts), 'r').read()

def find_version(*parts):
    version_file = read(*parts)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

long_description = read('README.rst')

setup(
    name='channelpack',
    version=find_version('channelpack', '__init__.py'),
    description='Callable container of Numpy arrays with support for masking and slicing',
    long_description=long_description,
    url='https://github.com/tomnor/channelpack',
    author='Tomas Nordin',
    author_email='tomnor@posteo.net',
    license='GPLv3+',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        ],
    keywords='data-mining datafile daq masking conditions evaluation ad-hoc',
    packages=['channelpack'],
    install_requires=['xlrd'],
)

==> channelpack-0.7.0.tar.gz: channelpack-0.7.0/setup.py <==
from setuptools import setup, find_packages
import codecs
import os
import re

here = os.path.abspath(os.path.dirname(__file__))

def read(*parts):
    # intentionally *not* adding an encoding option to open, See:
    #   https://github.com/pypa/virtualenv/issues/201#issuecomment-3145690
    return codecs.open(os.path.join(here, *parts), 'r').read()

def find_version(*parts):
    version_file = read(*parts)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")

long_description = read('README.rst')

setup(
    name='channelpack',
    version=find_version('channelpack', '__init__.py'),
    description='Callable container of Numpy arrays with support for masking and slicing',
    long_description=long_description,
    url='https://github.com/tomnor/channelpack',
    author='Tomas Nordin',
    author_email='tomnor@posteo.net',
    license='GPLv3+',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        ],
    keywords='data-mining datafile daq masking conditions evaluation ad-hoc',
    packages=['channelpack', 'channelpack.xlrd'],
    install_requires=[],
)
